@@ -42,12 +42,19 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('spice/enabled').with_value(false)
       end
 
-      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('512') }
+      it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_disk_mb').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_huge_pages').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('60') }
-      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value(true) }
+      it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/update_resources_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/reboot_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/instance_build_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/rescue_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/shutdown_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('glance/verify_glance_signatures').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_builds').with_value('<SERVICE DEFAULT>') }
@@ -57,6 +64,12 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/live_migration_wait_for_vif_plug').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/max_disk_devices_to_attach').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/default_access_ip_network_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_action').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_poll_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/compute_monitors').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/default_ephemeral_format').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to_not contain_package('bridge-utils').with(
         :ensure => 'present',
@@ -79,12 +92,19 @@ describe 'nova::compute' do
         { :enabled                            => false,
           :ensure_package                     => '2012.1-2',
           :vncproxy_host                      => '127.0.0.1',
+          :use_cow_images                     => false,
           :force_raw_images                   => false,
+          :virt_mkfs                          => 'windows=mkfs.ntfs --force --fast %(target)s',
           :reserved_host_memory               => '0',
           :reserved_host_disk                 => '20',
           :heal_instance_info_cache_interval  => '120',
           :config_drive_format                => 'vfat',
+          :update_resources_interval          => '300',
+          :reboot_timeout                     => '180',
+          :instance_build_timeout             => '300',
+          :rescue_timeout                     => '120',
           :resize_confirm_window              => '3',
+          :shutdown_timeout                   => '100',
           :resume_guests_state_on_host_boot   => true,
           :keymgr_backend                     => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           :barbican_endpoint                  => 'http://localhost',
@@ -98,6 +118,12 @@ describe 'nova::compute' do
           :consecutive_build_service_disable_threshold => '9',
           :live_migration_wait_for_vif_plug   => true,
           :max_disk_devices_to_attach         => 20,
+          :default_access_ip_network_name     => 'public',
+          :running_deleted_instance_action    => 'shutdown',
+          :running_deleted_instance_poll_interval => '900',
+          :running_deleted_instance_timeout   => '200',
+          :compute_monitors                   => ['cpu.virt_driver','fake'],
+          :default_ephemeral_format           => 'ext4',
         }
       end
 
@@ -136,11 +162,18 @@ describe 'nova::compute' do
         is_expected.to contain_nova_config('spice/enabled').with_value(false)
       end
 
+      it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value(false) }
+      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value(false) }
+      it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('windows=mkfs.ntfs --force --fast %(target)s') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('0') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_disk_mb').with_value('20') }
       it { is_expected.to contain_nova_config('DEFAULT/heal_instance_info_cache_interval').with_value('120') }
-      it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value(false) }
+      it { is_expected.to contain_nova_config('DEFAULT/update_resources_interval').with_value('300') }
+      it { is_expected.to contain_nova_config('DEFAULT/reboot_timeout').with_value('180') }
+      it { is_expected.to contain_nova_config('DEFAULT/instance_build_timeout').with_value('300') }
+      it { is_expected.to contain_nova_config('DEFAULT/rescue_timeout').with_value('120') }
       it { is_expected.to contain_nova_config('DEFAULT/resize_confirm_window').with_value('3') }
+      it { is_expected.to contain_nova_config('DEFAULT/shutdown_timeout').with_value('100') }
       it { is_expected.to contain_nova_config('DEFAULT/resume_guests_state_on_host_boot').with_value(true) }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_builds').with_value('15') }
       it { is_expected.to contain_nova_config('DEFAULT/max_concurrent_live_migrations').with_value('4') }
@@ -150,6 +183,12 @@ describe 'nova::compute' do
       it { is_expected.to contain_nova_config('compute/consecutive_build_service_disable_threshold').with_value('9') }
       it { is_expected.to contain_nova_config('compute/live_migration_wait_for_vif_plug').with_value(true) }
       it { is_expected.to contain_nova_config('compute/max_disk_devices_to_attach').with_value(20) }
+      it { is_expected.to contain_nova_config('DEFAULT/default_access_ip_network_name').with_value('public') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_action').with_value('shutdown') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_poll_interval').with_value('900') }
+      it { is_expected.to contain_nova_config('DEFAULT/running_deleted_instance_timeout').with_value('200') }
+      it { is_expected.to contain_nova_config('DEFAULT/compute_monitors').with_value('cpu.virt_driver,fake') }
+      it { is_expected.to contain_nova_config('DEFAULT/default_ephemeral_format').with_value('ext4') }
 
       it 'configures nova config_drive_format to vfat' do
         is_expected.to contain_nova_config('DEFAULT/config_drive_format').with_value('vfat')
