@@ -43,6 +43,8 @@ describe 'nova' do
       end
 
       it 'configures various things' do
+        is_expected.to contain_nova_config('glance/endpoint_override').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('glance/num_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova')
         is_expected.to contain_nova_config('oslo_concurrency/lock_path').with_value(platform_params[:lock_path])
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
@@ -61,6 +63,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -74,6 +77,7 @@ describe 'nova' do
       let :params do
         {
           :glance_endpoint_override                => 'http://localhost:9292',
+          :glance_num_retries                      => 3,
           :glance_api_servers                      => ['http://localhost:9292', 'http://localhost:9293'],
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
@@ -110,6 +114,8 @@ describe 'nova' do
           :key                                     => '/etc/ssl/certs/snakeoil.pem',
           :console_ssl_ciphers                     => 'kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES',
           :console_ssl_minimum_version             => 'tlsv1_2',
+          :dhcp_domain                             => 'foo',
+
         }
       end
 
@@ -124,11 +130,9 @@ describe 'nova' do
         })
       end
 
-      it 'configures glance endpoint_override' do
+      it 'configures glance parameters' do
         is_expected.to contain_nova_config('glance/endpoint_override').with_value('http://localhost:9292')
-      end
-
-      it 'configures glance api servers' do
+        is_expected.to contain_nova_config('glance/num_retries').with_value(3)
         is_expected.to contain_nova_config('glance/api_servers').with_value(['http://localhost:9292', 'http://localhost:9293'])
       end
 
@@ -180,6 +184,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
         is_expected.to contain_nova_config('console/ssl_ciphers').with_value('kEECDH+aECDSA+AES:kEECDH+AES+aRSA:kEDH+aRSA+AES')
         is_expected.to contain_nova_config('console/ssl_minimum_version').with_value('tlsv1_2')
+        is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('foo')
       end
 
       context 'with multiple notification_driver' do
